@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention AD Connector
 #  Univention LDAP Listener script for the ad connector
@@ -34,15 +33,13 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import, annotations
+from __future__ import annotations
 
 import os
+import pickle  # noqa: S403
 import shutil
 import subprocess
 import time
-from typing import Dict, List, Tuple
-
-from six.moves import cPickle as pickle
 
 import univention.debug as ud
 
@@ -71,7 +68,7 @@ if not dirs:
     raise ImportError('UCR variable connector/ad/listener/dir needs to be set!')
 
 
-def _save_old_object(directory: str, dn: str, old: Dict[str, List[bytes]] | None) -> None:
+def _save_old_object(directory: str, dn: str, old: dict[str, list[bytes]] | None) -> None:
     filename = os.path.join(directory, 'tmp', 'old_dn')
 
     with open(filename, 'wb+') as fd:
@@ -81,7 +78,7 @@ def _save_old_object(directory: str, dn: str, old: Dict[str, List[bytes]] | None
         p.clear_memo()
 
 
-def _load_old_object(directory: str) -> Tuple[str, Dict[str, List[bytes]]]:
+def _load_old_object(directory: str) -> tuple[str, dict[str, list[bytes]]]:
     with open(os.path.join(directory, 'tmp', 'old_dn'), 'rb') as fd:
         p = pickle.Unpickler(fd)
         (old_dn, old_object) = p.load()
@@ -89,7 +86,7 @@ def _load_old_object(directory: str) -> Tuple[str, Dict[str, List[bytes]]]:
     return (old_dn, old_object)
 
 
-def _dump_changes_to_file_and_check_file(directory: str, dn: str, new: Dict[str, List[bytes]] | None, old: Dict[str, List[bytes]] | None, old_dn: str | None) -> None:
+def _dump_changes_to_file_and_check_file(directory: str, dn: str, new: dict[str, list[bytes]] | None, old: dict[str, list[bytes]] | None, old_dn: str | None) -> None:
     ob = (dn, new, old, old_dn)
 
     tmpdir = os.path.join(directory, 'tmp')
@@ -118,7 +115,7 @@ def _restart_connector() -> None:
         listener.unsetuid()
 
 
-def handler(dn: str, new: Dict[str, List[bytes]] | None, old: Dict[str, List[bytes]] | None, command: str) -> None:
+def handler(dn: str, new: dict[str, list[bytes]] | None, old: dict[str, list[bytes]] | None, command: str) -> None:
     global connector_needs_restart
 
     # restart connector on extended attribute changes
@@ -136,7 +133,7 @@ def handler(dn: str, new: Dict[str, List[bytes]] | None, old: Dict[str, List[byt
                 os.makedirs(os.path.join(directory, 'tmp'))
 
             old_dn = None
-            old_object: Dict[str, List[bytes]] = {}
+            old_object: dict[str, list[bytes]] = {}
 
             if os.path.exists(os.path.join(directory, 'tmp', 'old_dn')):
                 (old_dn, old_object) = _load_old_object(directory)
